@@ -2,8 +2,8 @@ from mootdx import config
 from mootdx.consts import EX_HOSTS
 from mootdx.consts import GP_HOSTS
 from mootdx.consts import HQ_HOSTS
-from mootdx.server import Server
+from mootdx.server import server
 from mootdx.utils import get_config_path
 
-__version__ = '0.8.12'
+__version__ = '0.8.13'
 __author__ = 'bopo.wang<ibopo@126.com>'
