@@ -16,13 +16,15 @@ from mootdx.consts import MARKET_SH, return_last_value
 from mootdx.logger import logger
 from mootdx.utils import get_stock_market
 from mootdx.utils import get_stock_markets
+from mootdx.utils import get_frequency
 from mootdx.utils import to_data
 
 
 class Quotes(object):
     @staticmethod
     def factory(market='std', **kwargs):
-        """ 股票市场 工厂方法
+        """
+        股票市场 工厂方法
 
         :param market:  std 股票市场, ext 扩展市场， 默认股票市场
         :param kwargs:  可变参数
@@ -72,12 +74,16 @@ class BaseQuotes(object):
 
         return False
 
+    def pool(self):
+        ...
+
 
 instance: BaseQuotes
 
 
 def check_empty(value):
-    """ 重试判断函数
+    """
+    重试判断函数
 
     :param value: 要判断的值
     :return:
@@ -93,7 +99,8 @@ def check_empty(value):
 
 
 class StdQuotes(BaseQuotes):
-    """ 股票市场实时行情 """
+    """
+    股票市场实时行情 """
 
     def __init__(self, bestip=False, timeout=15, **kwargs):
         """ 构造函数
@@ -110,12 +117,15 @@ class StdQuotes(BaseQuotes):
         except ValueError as ex:
             logger.warning(ex)
         finally:
-            default = config.get('SERVER').get('HQ')[0]
+            default = config.get('SERVER').get('HQ')[0][1:]
             self.bestip = config.get('BESTIP').get('HQ', default)
 
         if kwargs.get('quiet'):
             del kwargs['quiet']
 
+        # ip_pool = AvailableIPPool(TdxHq_API, config.get('SERVER').get('HQ')[:5])
+        # self.client = TdxHqPool_API(TdxHq_API, ip_pool)
+
         self.client = TdxHq_API(raise_exception=False, **kwargs)
         self.client.connect(*self.bestip)
 
@@ -128,7 +138,8 @@ class StdQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def quotes(self, symbol=None, **kwargs):
-        """ 获取实时日行情数据
+        """
+        获取实时日行情数据
 
         :param symbol: 股票代码
         :return: pd.dataFrame or None
@@ -147,26 +158,26 @@ class StdQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def bars(self, symbol='000001', frequency=9, start=0, offset=100, **kwargs):
-        """ 获取实时日K线数据
+        """
+        获取实时日K线数据
 
         :param symbol: 股票代码
-        :param frequency: 数据类别
+        :param frequency: 数据频次
         :param start: 开始位置
         :param offset: 每次获取条数
         :return: pd.dataFrame or None
         """
-
+        frequency = get_frequency(frequency)
         market = get_stock_market(symbol)
         offset = 800 if int(offset) >= 800 else offset
-        result = self.client.get_security_bars(
-            int(frequency), int(market), str(symbol), int(start), int(offset)
-        )
+        result = self.client.get_security_bars(int(frequency), int(market), str(symbol), int(start), int(offset))
 
         return to_data(result, symbol=symbol, **kwargs)
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def stock_count(self, market=MARKET_SH):
-        """ 获取市场股票数量
+        """
+        获取市场股票数量
 
         :param market: 股票市场代码 sh 上海， sz 深圳
         :return: pd.dataFrame or None
@@ -178,7 +189,8 @@ class StdQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def stocks(self, market=MARKET_SH):
-        """ 获取股票列表
+        """
+        获取股票列表
 
         :param market: 股票市场
         :return:
@@ -189,25 +201,24 @@ class StdQuotes(BaseQuotes):
 
         for start in tqdm(range(0, counts, 1000)):
             result = self.client.get_security_list(market=market, start=start)
-            stocks = (
-                pandas.concat([stocks, to_data(result)], ignore_index=True)
-                if start > 1
-                else to_data(result)
-            )
+            stocks = (pandas.concat([stocks, to_data(result)], ignore_index=True) if start > 1 else to_data(result))
 
         return stocks
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def index_bars(self, symbol='000001', frequency=9, start=0, offset=100, **kwargs):
-        """ 获取指数k线
+        """
+        获取指数k线
 
         :param symbol: 股票代码
-        :param frequency: bar 类型
+        :param frequency: 数据频次
         :param start: 开始位置
         :param offset: 获取数量
         :return:
         """
 
+        frequency = get_frequency(frequency)
+
         market = get_stock_market(symbol)
         result = self.client.get_index_bars(frequency=frequency, market=market, code=symbol, start=start, count=offset)
 
@@ -215,7 +226,8 @@ class StdQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def minute(self, symbol='', **kwargs):
-        """ 获取实时分时数据
+        """
+        获取实时分时数据
 
         :param symbol: 股票代码
         :return: pd.DataFrame
@@ -228,7 +240,8 @@ class StdQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def minutes(self, symbol='', date='20191023', **kwargs):
-        """ 分时历史数据
+        """
+        分时历史数据
 
         :param symbol:  股票代码
         :param date:    查询日期
@@ -242,7 +255,8 @@ class StdQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def transaction(self, symbol='', start=0, offset=10, **kwargs):
-        """ 查询分笔成交
+        """
+        查询分笔成交
 
         :param symbol:  股票代码
         :param start:   起始位置
@@ -257,7 +271,8 @@ class StdQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def transactions(self, symbol='', start=0, offset=10, date='20170209', **kwargs):
-        """ 查询历史分笔成交
+        """
+        查询历史分笔成交
 
         :param symbol:  股票代码
         :param start:   起始位置
@@ -267,42 +282,44 @@ class StdQuotes(BaseQuotes):
         """
 
         market = get_stock_market(symbol, string=False)
-        result = self.client.get_history_transaction_data(
-            market=market, code=symbol, start=start, count=offset, date=int(date)
-        )
+        result = self.client.get_history_transaction_data(market=market, code=symbol, start=start, count=offset, date=int(date))
 
         return to_data(result, symbol=symbol, **kwargs)
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def F10C(self, symbol=''):
-        """ 查询公司信息目录
+    def F10C(self, symbol=''):  # noqa
+        """
+        查询公司信息目录
 
         :param symbol: 股票代码
         :return: pd.dataFrame or None
         """
+
         market = int(get_stock_market(symbol))
         result = self.client.get_company_info_category(market, symbol)
 
         return result
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def F10(self, symbol='', name=''):
-        """ 读取公司信息详情
+    def F10(self, symbol='', name=''):  # noqa
+        """
+        读取公司信息详情
 
         :param name: 公司 F10 标题
         :param symbol: 股票代码
         :return: pd.dataFrame or None
         """
+
         result = {}
         market = int(get_stock_market(symbol, string=False))
 
-        frequency = self.client.get_company_info_category(market, symbol)
+        category = self.client.get_company_info_category(market, symbol)
 
-        if not frequency:
+        if not category:
             return None
 
         if name:
-            for x in frequency:
+            for x in category:
                 if x['name'] == name:
                     return self.client.get_company_info_content(
                         market=market,
@@ -312,20 +329,15 @@ class StdQuotes(BaseQuotes):
                         length=x['length'],
                     )
 
-        for x in frequency:
-            result[x['name']] = self.client.get_company_info_content(
-                market=market,
-                code=symbol,
-                filename=x['filename'],
-                start=x['start'],
-                length=x['length'],
-            )
+        for x in category:
+            result[x['name']] = self.client.get_company_info_content(market=market, code=symbol, filename=x['filename'], start=x['start'], length=x['length'])
 
         return result
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def xdxr(self, symbol='', **kwargs):
-        """ 读取除权除息信息
+        """
+        读取除权除息信息
 
         :param symbol: 股票代码
         :return: pd.dataFrame or None
@@ -338,7 +350,8 @@ class StdQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def finance(self, symbol='000001', **kwargs):
-        """ 读取财务信息
+        """
+        读取财务信息
 
         :param symbol: 股票代码
         :return:
@@ -351,7 +364,8 @@ class StdQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def k(self, symbol='', begin=None, end=None):
-        """ 读取k线信息
+        """
+        读取k线信息
 
         :param symbol:  股票代码
         :param begin:   开始日期
@@ -359,12 +373,27 @@ class StdQuotes(BaseQuotes):
         :return: pd.dataFrame or None
         """
 
-        result = self.client.get_k_data(symbol, begin, end)
+        result = self.get_k_data(symbol, begin, end)
         return result
 
+    def ohlc(self, **kwargs):
+        return self.k(**kwargs)
+
+    def get_k_data(self, code, start_date, end_date):
+
+        # !! todo
+        data = pd.concat([self.client.to_df(self.client.get_security_bars(9, get_stock_market(code), code, (9 - i) * 800, 800)) for i in range(10)], axis=0)
+        data = data.assign(date=data['datetime'].apply(lambda x: str(x)[0:10])).assign(code=str(code))
+        data = data.set_index('date', drop=False, inplace=False)
+        data = data.drop(['year', 'month', 'day', 'hour', 'minute', 'datetime'], axis=1)[start_date:end_date]
+        data = data.assign(date=data['date'].apply(lambda x: str(x)[0:10]))
+
+        return data
+
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def index(self, symbol='000001', market=MARKET_SH, frequency=9, start=1, offset=2, **kwargs):
-        """ 获取指数k线
+        """
+        获取指数k线
 
         K线种类:
         - 0 5分钟K线
@@ -374,7 +403,6 @@ class StdQuotes(BaseQuotes):
         - 4 日K线
         - 5 周K线
         - 6 月K线
-
         - 7 1分钟
         - 8 1分钟K线
         - 9 日K线
@@ -382,22 +410,21 @@ class StdQuotes(BaseQuotes):
         - 11 年K线
 
         :param symbol:      股票代码
-        :param frequency:   数据类别
+        :param frequency:   数据频次
         :param market:      证券市场
         :param start:       开始位置
         :param offset:      每次获取条数
         :return: pd.dataFrame or None
         """
 
-        result = self.client.get_index_bars(
-            int(frequency), int(market), str(symbol), int(start), int(offset)
-        )
+        result = self.client.get_index_bars(int(frequency), int(market), str(symbol), int(start), int(offset))
 
         return to_data(result, symbol=symbol, **kwargs)
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def block(self, tofile='block.dat', **kwargs):
-        """ 获取证券板块信息
+        """
+        获取证券板块信息
 
         :param tofile: 保存文件
         :return: pd.dataFrame or None
@@ -413,7 +440,8 @@ class ExtQuotes(BaseQuotes):
     bestip = ('112.74.214.43', 7727)
 
     def __init__(self, bestip=False, timeout=15, **kwargs):
-        """ 构造函数
+        """
+        构造函数
 
         :param bestip:  最优服务器IP
         :param timeout: 超时时间
@@ -439,7 +467,8 @@ class ExtQuotes(BaseQuotes):
 
     @staticmethod
     def validate(market, symbol):
-        """ 验证股票市场
+        """
+        验证股票市场
 
         :param market: 股票市场
         :param symbol: 股票代码
@@ -458,7 +487,8 @@ class ExtQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def markets(self, **kwargs):
-        """ 获取实时市场列表
+        """
+        获取实时市场列表
 
         :return: pd.dataFrame or None
         """
@@ -468,7 +498,8 @@ class ExtQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def instrument(self, start=0, offset=100, **kwargs):
-        """ 查询代码列表
+        """
+        查询代码列表
 
         :param start:   开始位置
         :param offset:  获取数量
@@ -480,7 +511,8 @@ class ExtQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def instrument_count(self):
-        """ 市场商品数量
+        """
+        市场商品数量
 
         :return:
         """
@@ -491,7 +523,8 @@ class ExtQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def instruments(self, **kwargs):
-        """ 查询所有代码列表
+        """
+        查询所有代码列表
 
         :return:
         """
@@ -508,7 +541,8 @@ class ExtQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def quote(self, market='', symbol='', **kwargs):
-        """ 查询五档行情
+        """
+        查询五档行情
 
         :param market: 市场ID
         :param symbol: 证券代码
@@ -522,7 +556,8 @@ class ExtQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def minute(self, market='', symbol='', **kwargs):
-        """ 查询分时行情
+        """
+        查询分时行情
 
         :param market: 市场ID
         :param symbol: 证券代码
@@ -536,7 +571,8 @@ class ExtQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def minutes(self, market=None, symbol='', date='', **kwargs):
-        """ 查询历史分时行情
+        """
+        查询历史分时行情
 
         :param market:  市场ID
         :param symbol:  证券代码
@@ -551,9 +587,10 @@ class ExtQuotes(BaseQuotes):
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def bars(self, frequency='', market='', symbol='', start=0, offset=100, **kwargs):
-        """ 查询k线数据
+        """
+        查询k线数据
 
-        :param frequency: K线周期
+        :param frequency: 数据频次, K线周期
         :param market: 市场ID
         :param symbol: 证券代码
         :param start:  起始位置
@@ -561,16 +598,17 @@ class ExtQuotes(BaseQuotes):
         :return:
         """
 
+        frequency = get_frequency(frequency)
+
         market, symbol = self.validate(market, symbol)
-        result = self.client.get_instrument_bars(
-            category=frequency, market=market, code=symbol, start=start, count=offset
-        )
+        result = self.client.get_instrument_bars(category=frequency, market=market, code=symbol, start=start, count=offset)
 
         return to_data(result, symbol=symbol, **kwargs)
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def transaction(self, market=None, symbol='', start=0, offset=1800, **kwargs):
-        """ 查询分笔成交
+        """
+        查询分笔成交
 
         :param market: 市场ID
         :param symbol: 证券代码
@@ -580,15 +618,14 @@ class ExtQuotes(BaseQuotes):
         """
 
         market, symbol = self.validate(market, symbol)
-        result = self.client.get_transaction_data(
-            market=market, code=symbol, start=start, count=offset
-        )
+        result = self.client.get_transaction_data(market=market, code=symbol, start=start, count=offset)
 
         return to_data(result, symbol=symbol, **kwargs)
 
     @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
     def transactions(self, market=None, symbol='', date='', start=0, offset=1800, **kwargs):
-        """ 查询历史分笔成交
+        """
+        查询历史分笔成交
 
         :param market:  市场ID
         :param symbol:  证券代码
@@ -599,8 +636,6 @@ class ExtQuotes(BaseQuotes):
         """
 
         market, symbol = self.validate(market, symbol)
-        result = self.client.get_history_transaction_data(
-            market=market, code=symbol, date=int(date), start=start, count=offset
-        )
+        result = self.client.get_history_transaction_data(market=market, code=symbol, date=int(date), start=start, count=offset)
 
         return to_data(result, symbol=symbol, **kwargs)
